#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 executable-path
version:              0.0.3.1
visibility:           public
id:                   executable-path-0.0.3.1-AU3Ex0ZBY1N76ZvxYyAAfg
key:                  executable-path-0.0.3.1-AU3Ex0ZBY1N76ZvxYyAAfg
license:              LicenseRef-PublicDomain
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".

category:             System
abi:                  9b8391b84f56caae999870b1f97acd95
exposed:              True
exposed-modules:      System.Environment.Executable
hidden-modules:       System.Environment.Executable.Linux
import-dirs:          /usr/lib/ghc-9.6.6/site-local/executable-path-0.0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/executable-path-0.0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-executable-path
hs-libraries:         HSexecutable-path-0.0.3.1-AU3Ex0ZBY1N76ZvxYyAAfg
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-executable-path/html/executable-path.haddock

haddock-html:         /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

